Skip site navigation (1)Skip section navigation (2)

  
 
  

home | help
XCPUSTATE(1)		     General Commands Manual		    XCPUSTATE(1)

NAME
     xcpustate - display CPU states (idle, nice, system, kernel) statistics

SYNTAX
     xcpustate [ -toolkitoption ...] [ -count iterations] [ -interval seconds] [
     -shorten  components]  [  -cpu]  [  -nocpu]  [ -disk] [ -nodisk] [ -omni] [
     -noomni] [ -wait] [ -nowait] [ -filltype auto|grayscale|color|tile|stipple]
     [ -host hostname] [ -version]  [  -colors	colorname[,colorname[,...]]]   [
     -avg iterations][ -kernel pathname] [ -mmap] [ -nommap]

DESCRIPTION
     Xcpustate	displays  bars	showing the percentage of time the CPU spends in
     different states. On some systems, it optionally indicates disk  states  in
     the same manner. It can also query remote systems that offer RSTAT RPC ser-
     vices.

     When  using the RSTAT protocol, or when running locally on machines running
     Cygwin, or Berkeley Unix or a derivative (eg. suns with  SunOS<=4.1.1,  mi-
     croVaxen  with  Ultrix),  the  bar indicates the proportions of idle, user,
     nice, and system time with increasing levels of grayscale	or  color  (from
     left  to  right).	 When running locally on supported multiprocessors (Sol-
     bourne OS/MP systems, Ultrix  multiprocessors,  Linux/SMP,  and  the  Gould
     NP1), there will be one bar for each CPU.

     On  Linux	systems,  each	CPU bar indicates the proportions of idle, user,
     nice, and system time, respectively, from left to right.  Each  disk  drive
     bar  indicates  the proportions of idle, read I/O operations, and write I/O
     operations, from left to right. For disk drive bars, the I/O operations are
     displayed on a sliding scale, the entire bar corresponding to  the  maximum
     total  (read  and write) number of I/O operations per interval since xcpus-
     tate was started, and read/write I/O operations shown as fractions  of  the
     current  maximum.	For disk drive bar display under Linux, xcpustate relies
     on the "disk_io" statistics in /proc/stat (2.4 kernels) or the  information
     in /proc/diskstats (2.6 or later kernels).

     On systems running OpenBSD 3.0 or later, each CPU bar indicates the propor-
     tions  of	idle, user, nice, interrupt, and system time, respectively, from
     left to right.

     On an SGI system running IRIX, there will be one bar for each CPU, indicat-
     ing the proportions of idle + wait, user, kernel, sxbrk and interrupt  time
     for  that CPU. If the ``wait'' option is set, the bars indicate idle, wait,
     user, kernel, sxbrk, and interrupt time, from left to right.

     On a Sun multiprocessor under SunOS 4.1.2 or 4.1.3, bars indicate the  pro-
     portions  of  idle  + diskwait, user, nice, system, spinlock, and crosscall
     service time for each CPU.

     On a Sun or other system (eg. Solbourne, Cray Superserver-6400) running So-
     laris 2.x or later, and on an IBM system running  AIX,  bars  indicate  the
     proportions  of  idle  +  wait, user, and kernel time for each CPU.  If the
     ``wait'' option is set, the bars indicate idle, wait, user, and system/ker-
     nel time, from left to right.

     On a Cray X/MP or Y/MP running Unicos 5.1 or  greater,  bars  indicate  the
     proportions of idle + wait, user and system/kernel time for each CPU.

     On  systems  running  the Mach operating system, bars indicates the propor-
     tions of user, system, and idle time for each CPU.

     On supported SVR4 systems (e.g. Dell Unix 2.2), a single bar  is  displayed
     showing idle, user, system and wait times.

     On  NCR  SVR4  MP/RAS systems, one bar for each CPU (or disk drive) is dis-
     played.  Each bar indicates the relative proportions of idle, user,  system
     and wait times for that CPU.  Disk drive times show device idle and busy.

OPTIONS
     Xcpustate accepts all of the standard X Toolkit command line options, plus:

     -count iterations
	     The  number  of times it should update the display. Default is for-
	     ever.

     -avg iterations
	     The number of iterations the bar values should  be  averaged  over.
	     Default is one.

     -interval seconds
	     the interval in seconds (fractions permitted) between updates.  De-
	     fault is 1 second.

     -shorten components
	     On some systems, xcpustate will display the hostname in the bar la-
	     bels.   Since  some  fully qualified domain names can be very long,
	     this option allows them to be shortened to  a  specific  number  of
	     components.   eg.	 if  your  hostname is foo.wherever.edu, you can
	     shorten it to foo by specifying -shorten 1 or  to	foo.wherever  by
	     specifying  -shorten 2 .  Specifying -shorten 0 will omit the host-
	     name completely; a negative number will cause xcpustate to draw un-
	     labeled bars.  Some systems may not support this option.

     -cpu    Display CPU statistics (default).

     -nocpu  Do not display CPU statistics.

     -disk   Display Disk statistics. This is supported  only  on  Suns  running
	     SunOS 4.x or 5.x, on Linux systems, or when using RSTAT. One bar is
	     displayed	for  each  disk. Disk bars appear below the CPU bars, if
	     any. When using RSTAT, exactly four bars appear regardless  of  the
	     number  of  disks	on  the remote host (this is a limitation of the
	     current version of the RSTAT protocol). For Suns running SunOS 4.x,
	     the bars report idle, seek, and transfer  time.  For  Suns  running
	     SunOS 5.x, the bars report idle, wait, and run time. For Linux sys-
	     tems, the bars report idle, read I/O operations and write I/O oper-
	     ations.   When RSTAT is being used, the bars report idle and trans-
	     fer time.

     -nodisk
	     Do not display disk statistics (default).

     -omni   Display Omni Network Coprocessor Statistics. This is supported only
	     on Suns running SunOS 4.x. One bar is displayed  for  each  Network
	     Coprocessor,  and placed immediately below the bars for the regular
	     CPU(s). Each bar indicates idle and system time.

     -noomni
	     Do not display omni statistics (default).

     -wait   Display CPU disk/system wait time as a separate  statistic  on  ap-
	     plicable systems (Eg. SunOS 5.x, SGI IRIX, IBM AIX).

     -nowait
	     Include CPU disk/system wait time as part of idle (default).

     -version
	     Print out version information and exit.

     -filltype
	     Specify the method xcpustate should use to fill the bars. Available
	     options  include grayscale, color, tile, stipple, or auto. Auto au-
	     tomatically chooses between tiling, grayscale, and colour,  depend-
	     ing on your display type. Auto is the default.

     -colors
	     Specify  the  colors used to draw the bars. Colors are specified in
	     left-to-right order, separated by commas. A single dot can be  used
	     to specify the default color at that position. Up to ten colors may
	     be  specified.   Defaults	are used for the leftmost colors if less
	     than ten are specified.

     -kernel pathname
	     Specify the path that xcpustate will use to find kernel symbol file
	     information on some systems. This option is ignored on IRIX,  Mach,
	     and SunOS 5.x.

     -mmap   Request  that xcpustate use mmap to directly map kernel memory into
	     the current process address space on some systems (SVR4  and  NCR).
	     This is the default.

     -nommap
	     Inverse of mmap option.

X DEFAULTS
     For xcpustate the available class identifiers are:

     CPUStateMonitor - the application
     Form - enclosing the entire application, and sub-Forms enclosing
     Label/Bar pairs.

     For xcpustate, the available name identifiers are:

     xcpustate - application name
     The outer Form is "form".
     The Forms enclosing the Label/Bar pairs are "formN", where N is the
     index number, starting with the top pair as zero.
     Each Label name is the same as the label string.
     Each Bar name is "barN".

     For xcpustate, the available resources are:

     name interval, class Interval
	    corresponds to the -interval option. Takes a float value.

     name count, class Count
	    corresponds to the -count argument. Takes an integer value.

     name avg, class Avg
	    corresponds to the -avg argument. Takes an integer value.

     name shorten, class Shorten
	    corresponds to the -shorten argument. Takes an integer value.

     name cpu, class Cpu
	    corresponds to the -cpu and -nocpu arguments. Takes a boolean value.

     name disk, class Disk
	    corresponds  to  the  -disk  and  -nodisk arguments. Takes a boolean
	    value.

     name omni, class Omni
	    corresponds to the -omni and  -noomni  arguments.  Takes  a  boolean
	    value.  Not available on systems other than Suns running SunOS 4.x.

     name wait, class Wait
	    corresponds  to  the  -wait  and  -nowait arguments. Takes a boolean
	    value.

     name filltype, class Filltype
	    corresponds to the -filltype argument. Takes a string.

     name host, class Host
	    corresponds to the -host argument. Takes a hostname.

     name colors, class Colors
	    corresponds to the -colors argument. Takes a comma-separated list of
	    color names.

     name mmap, class Mmap
	    corresponds to the -mmap  and  -nommap  argument.  Takes  a  boolean
	    value.

     name kernel, class Kernel
	    corresponds to the -kernel argument. Takes a pathname.

NOTES
     Xcpustate is meant to be easy to port, and extend to monitor a wide variety
     of statistics.

SEE ALSO
     xperfmon, xload, xmeter

AUTHORS
     Mark  Moraes at D. E. Shaw wrote the original X code and the SGI IRIX code.
     He also enhanced the code for the Bar widget to support  color.   John  Di-
     Marco  at	the  University  of  Toronto  is the current maintainer. He con-
     tributed to the color support, fixed some minor problems, added support for
     SunOS 4.x multiprocessors, SunOS 5.x, disks, Omni network coprocessors, AIX
     (SMP on AIX 4.x) and RSTAT. Thanks to David O'Brien of  the  University  of
     California,  Davis  for the 4.4BSD code, Chris Siebenmann of the University
     of Toronto for the code for 4.3BSD systems; Walter D. Poxon from  Cray  Re-
     search  for  the code for Cray machines running Unicos; Melinda Shore at mt
     Xinu for the code for Mach systems; Bill Kucharski  at  Solbourne	for  the
     code  for	Solbourne  systems; Salvador Pinto Abreu at Universidade Nova de
     Lisboa, Portugal, for the code for Ultrix multiprocessors; Hugues Leroy  at
     Irisa, Rennes, France for the code for Gould NP1 bi-processors, Bruce Frost
     at  NCR for the code for (Dell) SVR4 and NCR systems, and Kumsup Lee at the
     University of Minnesota and Greg Nakhimovsky at Sun  Microsystems	for  the
     Linux code. Thanks also to Robert Montjoy from the University of Cincinatti
     for  contributing and testing some of the SunOS 5.x code, to Dave Cahlander
     from Cray for cleaning up the X resource code, and to Ron Wigmore from  Ry-
     erson Polytechnic University for his assistance with the AIX port.

BUGS
     The  RSTAT  RPC  protocol supports only one processor and four disks on the
     remote system. On a multiprocessor, the CPU data reported by RSTAT will  be
     an average of all the active CPUs on the machine.

     For  some	operating  systems, there may be internal compile-time limits on
     the number of CPUs or disks supported.  If there are  compile-time  limits,
     they are reported by the output of the -version flag.

     Xcpustate	may initially display nonsensical data, before being updated the
     first time.

     The use of very small (significantly less than one  second)  intervals  may
     result  in xcpustate using significant resources, particularly when running
     over the network.	A minimum interval may be specified  as  a  compile-time
     option, and intervals less than this will not be permitted.

				  Mar 29, 1996			    XCPUSTATE(1)

Want to link to this manual page? Use this URL:
<https://man.freebsd.org/cgi/man.cgi?query=xcpustate&sektion=1&manpath=FreeBSD+Ports+15.1.quarterly>

home | help